ThumbnailException class

Exception thrown when thumbnail generation fails

Implemented types

Constructors

ThumbnailException(String message, [Object? error, StackTrace? stackTrace])
Creates a new ThumbnailException instance.
const

Properties

error Object?
The underlying error if any
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace if available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited