ThumbnailResult class

Result of a thumbnail generation operation

Constructors

ThumbnailResult({required List<int> data, required int width, required int height, required ThumbnailFormat format, required double timePosition, required int size})
Creates a new ThumbnailResult instance.
const

Properties

data List<int>
The generated thumbnail data as bytes
final
format ThumbnailFormat
The format of the generated thumbnail
final
hashCode int
The hash code for this object.
no setterinherited
height int
The height of the generated thumbnail
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The file size in bytes
final
timePosition double
The time position where the thumbnail was generated
final
width int
The width of the generated thumbnail
final

Methods

copyWith({List<int>? data, int? width, int? height, ThumbnailFormat? format, double? timePosition, int? size}) ThumbnailResult
Creates a copy of this object with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited