ThumbnailOptions class
Configuration options for thumbnail generation
Constructors
- ThumbnailOptions({required double timePosition, int width = 320, int height = 240, double quality = 0.8, ThumbnailFormat format = ThumbnailFormat.jpeg, bool maintainAspectRatio = true})
-
Creates a new ThumbnailOptions instance.
const
Properties
- format → ThumbnailFormat
-
The output format for the thumbnail
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The height of the thumbnail in pixels
final
- maintainAspectRatio → bool
-
Whether to maintain aspect ratio
final
- quality → double
-
The quality of the thumbnail (0.0 to 1.0)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timePosition → double
-
The time position in seconds where the thumbnail should be generated
final
- width → int
-
The width of the thumbnail in pixels
final
Methods
-
copyWith(
{double? timePosition, int? width, int? height, double? quality, ThumbnailFormat? format, bool? maintainAspectRatio}) → ThumbnailOptions - Creates a copy of this object with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited